@@ -2,7 +2,7 @@ from httpx import BasicAuth
 
 
 class Base:
-    def __init__(self, email: str, password: str) -> None:
+    def __init__(self, email: str, password: str, timeout: int = 60) -> None:
         """Used to create Dathost basic auth.
 
         Parameters
@@ -11,6 +11,9 @@ class Base:
             Email of dathost account.
         password : str
             Password of dathost account.
+        timeout : int, optional
+            by default 60
         """
 
         self._basic_auth = BasicAuth(email, password)
+        self._timeout = timeout
